Index: funcs/func_logic.c
===================================================================
RCS file: /usr/cvsroot/asterisk/funcs/func_logic.c,v
retrieving revision 1.5
diff -u -u -r1.5 func_logic.c
--- funcs/func_logic.c	20 May 2005 16:30:13 -0000	1.5
+++ funcs/func_logic.c	3 Jun 2005 15:11:48 -0000
@@ -35,7 +35,53 @@
 	return data && *data ? ret_true : ret_false;
 }
 
-static char *builtin_function_if(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) 
+static char *builtin_function_iftime(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) 
+{
+	struct ast_timing timing;
+	char *ret = NULL, *expr = NULL;
+	int res = 0;
+
+	if (!(expr = ast_strdupa(data))) {
+		ast_log(LOG_WARNING, "Memory Error!\n");
+	} else {
+		char *iftrue = NULL;
+		char *iffalse = NULL;
+
+		expr = ast_strip_quoted(expr, "\"", "\"");
+		if ((iftrue = strchr(expr, '?'))) {
+			*iftrue = '\0';
+			iftrue++;
+			if ((iffalse = strchr(iftrue, ':'))) {
+				*iffalse = '\0';
+				iffalse++;
+			}
+		}
+		if (!(res = ast_build_timing(&timing, expr))) {
+            ast_log(LOG_WARNING, "Invalid Time Spec.\n");
+        } else {
+			if (expr && iftrue) {
+				iftrue = ast_strip_quoted(iftrue, "\"", "\"");
+
+				if (iffalse) {
+					iffalse = ast_strip_quoted(iffalse, "\"", "\"");
+				}
+				ret = ast_check_timing(&timing) ? iftrue : iffalse;
+				if (ret) {
+					ast_copy_string(buf, ret, len);
+					ret = buf;
+				}
+			} else {
+				ast_log(LOG_WARNING, "Syntax IFTIME(<timespec>?[<truecond>][:<falsecond>])\n");
+				ret = NULL;
+			}
+		}
+	} 
+	
+    return ret;
+
+}
+
+static char *builtin_function_if (struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) 
 {
 	char *ret = NULL;
 	char *mydata = NULL;
@@ -43,7 +89,7 @@
 	char *iftrue = NULL;
 	char *iffalse = NULL;
 
-	if((mydata = ast_strdupa(data))) {
+	if ((mydata = ast_strdupa(data))) {
 		expr = mydata;
 		if ((iftrue = strchr(mydata, '?'))) {
 			*iftrue = '\0';
@@ -67,7 +113,7 @@
 				ret = buf;
 			}
 		} else {
-			ast_log(LOG_WARNING, "Syntax $(if <expr>?[<truecond>][:<falsecond>])\n");
+			ast_log(LOG_WARNING, "Syntax IF (<expr>?[<truecond>][:<falsecond>])\n");
 			ret = NULL;
 		}
 	} else {
@@ -139,4 +185,15 @@
 	.synopsis = "Conditional: Returns the data following '?' if true else the data following ':'",
 	.syntax = "IF(<expr>?<true>:<false>)",
 	.read = builtin_function_if,
+};
+
+
+#ifndef BUILTIN_FUNC
+static
+#endif
+struct ast_custom_function if_time_function = {
+	.name = "IFTIME",
+	.synopsis = "Temporal Conditional: Returns the data following '?' if true else the data following ':'",
+	.syntax = "IFTIME(<timespec>?<true>:<false>)",
+	.read = builtin_function_iftime,
 };
